@@ -24,6 +24,6 @@ check_beast2_optionses <- function(
   }
   for (i in seq_along(beast2_optionses)) {
     # Stub with too simple error message
-    check_beast2_options(beast2_optionses[[i]]) # nolint beastier function
+    beastier::check_beast2_options(beast2_optionses[[i]])
   }
 }
