@@ -17,12 +17,12 @@
 #'   )
 #'
 #'   expect_equal(length(filenames), 4)
-#'   expect_true(files_exist(filenames))
+#'   expect_true(all(file.exists(filenames)))
 #' @export
 get_beastier_paths <- function(filenames) {
 
   for (i in seq_along(filenames)) {
-    filenames[i] <- get_beastier_path(filenames[i]) # nolint internal function
+    filenames[i] <- beastier::get_beastier_path(filenames[i])
   }
 
   filenames
